@@ -18,7 +18,6 @@
 package org.apache.kyuubi.sql
 
 import org.apache.spark.network.util.ByteUnit
-import org.apache.spark.sql.internal.SQLConf
 import org.apache.spark.sql.internal.SQLConf._
 
 object KyuubiSQLConf {
@@ -30,27 +29,6 @@ object KyuubiSQLConf {
       .booleanConf
       .createWithDefault(true)
 
-  val INSERT_REPARTITION_NUM =
-    buildConf("spark.sql.optimizer.insertRepartitionNum")
-      .doc(s"The partition number if ${INSERT_REPARTITION_BEFORE_WRITE.key} is enabled. " +
-        s"If AQE is disabled, the default value is ${SQLConf.SHUFFLE_PARTITIONS.key}. " +
-        "If AQE is enabled, the default value is none that means depend on AQE. " +
-        "This config is used for Spark 3.1 only.")
-      .version("1.2.0")
-      .intConf
-      .createOptional
-
-  val DYNAMIC_PARTITION_INSERTION_REPARTITION_NUM =
-    buildConf("spark.sql.optimizer.dynamicPartitionInsertionRepartitionNum")
-      .doc(s"The partition number of each dynamic partition if " +
-        s"${INSERT_REPARTITION_BEFORE_WRITE.key} is enabled. " +
-        "We will repartition by dynamic partition columns to reduce the small file but that " +
-        "can cause data skew. This config is to extend the partition of dynamic " +
-        "partition column to avoid skew but may generate some small files.")
-      .version("1.2.0")
-      .intConf
-      .createWithDefault(100)
-
   val FORCE_SHUFFLE_BEFORE_JOIN =
     buildConf("spark.sql.optimizer.forceShuffleBeforeJoin.enabled")
       .doc("Ensure shuffle node exists before shuffled join (shj and smj) to make AQE " +
@@ -273,4 +251,11 @@ object KyuubiSQLConf {
       .version("1.8.0")
       .stringConf
       .createOptional
+
+  val SCRIPT_TRANSFORMATION_ENABLED =
+    buildConf("spark.sql.execution.scriptTransformation.enabled")
+      .doc("When false, script transformation is not allowed.")
+      .version("1.9.0")
+      .booleanConf
+      .createWithDefault(true)
 }
