@@ -25,13 +25,12 @@ import scala.collection.JavaConverters._
 import scala.concurrent.duration.Duration
 import scala.util.control.NonFatal
 
-import org.apache.hive.service.rpc.thrift.TProtocolVersion
-
 import org.apache.kyuubi.{KyuubiSQLException, Utils}
 import org.apache.kyuubi.config.KyuubiConf
 import org.apache.kyuubi.config.KyuubiConf._
 import org.apache.kyuubi.operation.OperationManager
 import org.apache.kyuubi.service.CompositeService
+import org.apache.kyuubi.shaded.hive.service.rpc.thrift.TProtocolVersion
 import org.apache.kyuubi.util.ThreadUtils
 import org.apache.kyuubi.util.ThreadUtils.scheduleTolerableRunnableWithFixedDelay
 
@@ -93,7 +92,7 @@ abstract class SessionManager(name: String) extends CompositeService(name) {
   protected def logSessionCountInfo(session: Session, action: String): Unit = {
     info(s"${session.user}'s ${session.getClass.getSimpleName} with" +
       s" ${session.handle}${session.name.map("/" + _).getOrElse("")} is $action," +
-      s" current opening sessions $getActiveUserSessionCount")
+      s" current opening sessions $getOpenSessionCount")
   }
 
   def openSession(
@@ -104,16 +103,16 @@ abstract class SessionManager(name: String) extends CompositeService(name) {
       conf: Map[String, String]): SessionHandle = {
     info(s"Opening session for $user@$ipAddress")
     val session = createSession(protocol, user, password, ipAddress, conf)
-    val handle = session.handle
     try {
-      setSession(handle, session)
+      val handle = session.handle
       session.open()
+      setSession(handle, session)
       logSessionCountInfo(session, "opened")
       handle
     } catch {
       case e: Exception =>
         try {
-          closeSession(handle)
+          session.close()
         } catch {
           case t: Throwable =>
             warn(s"Error closing session for $user client ip: $ipAddress", t)
@@ -123,13 +122,11 @@ abstract class SessionManager(name: String) extends CompositeService(name) {
   }
 
   def closeSession(sessionHandle: SessionHandle): Unit = {
+    _latestLogoutTime = System.currentTimeMillis()
     val session = handleToSession.remove(sessionHandle)
     if (session == null) {
       throw KyuubiSQLException(s"Invalid $sessionHandle")
     }
-    if (!session.isForAliveProbe) {
-      _latestLogoutTime = System.currentTimeMillis()
-    }
     logSessionCountInfo(session, "closed")
     try {
       session.close()
@@ -162,10 +159,7 @@ abstract class SessionManager(name: String) extends CompositeService(name) {
     handleToSession.put(sessionHandle, session)
   }
 
-  /**
-   * Get the count of active user sessions, which excludes alive probe sessions.
-   */
-  def getActiveUserSessionCount: Int = handleToSession.values().asScala.count(!_.isForAliveProbe)
+  def getOpenSessionCount: Int = handleToSession.size()
 
   def allSessions(): Iterable[Session] = handleToSession.values().asScala
 
@@ -309,7 +303,7 @@ abstract class SessionManager(name: String) extends CompositeService(name) {
 
     val checkTask = new Runnable {
       override def run(): Unit = {
-        info(s"Checking sessions timeout, current count: $getActiveUserSessionCount")
+        info(s"Checking sessions timeout, current count: $getOpenSessionCount")
         val current = System.currentTimeMillis
         if (!shutdown) {
           for (session <- handleToSession.values().asScala) {
@@ -347,7 +341,7 @@ abstract class SessionManager(name: String) extends CompositeService(name) {
       val checkTask = new Runnable {
         override def run(): Unit = {
           if (!shutdown && System.currentTimeMillis() - latestLogoutTime > idleTimeout &&
-            getActiveUserSessionCount <= 0) {
+            getOpenSessionCount <= 0) {
             info(s"Idled for more than $idleTimeout ms, terminating")
             stop()
           }
