@@ -21,7 +21,6 @@ import java.time.Duration
 
 import scala.collection.JavaConverters._
 
-import org.apache.hive.service.rpc.thrift._
 import org.scalatest.time._
 
 import org.apache.kyuubi.{KyuubiFunSuite, KyuubiSQLException, Utils}
@@ -30,6 +29,7 @@ import org.apache.kyuubi.config.KyuubiConf._
 import org.apache.kyuubi.operation.{OperationHandle, TClientTestUtils}
 import org.apache.kyuubi.service.TFrontendService.FeServiceServerContext
 import org.apache.kyuubi.session.{AbstractSession, SessionHandle}
+import org.apache.kyuubi.shaded.hive.service.rpc.thrift._
 
 class TFrontendServiceSuite extends KyuubiFunSuite {
 
@@ -549,13 +549,13 @@ class TFrontendServiceSuite extends KyuubiFunSuite {
         .getSession(SessionHandle(handle))
         .asInstanceOf[AbstractSession]
       var lastAccessTime = session.lastAccessTime
-      assert(sessionManager.getActiveUserSessionCount === 1)
+      assert(sessionManager.getOpenSessionCount === 1)
       assert(session.lastIdleTime > 0)
 
       val cancelOpReq = new TCancelOperationReq(resp.getOperationHandle)
       val cancelOpResp = client.CancelOperation(cancelOpReq)
       assert(cancelOpResp.getStatus.getStatusCode === TStatusCode.SUCCESS_STATUS)
-      assert(sessionManager.getActiveUserSessionCount === 1)
+      assert(sessionManager.getOpenSessionCount === 1)
       assert(session.lastIdleTime === 0)
 
       lastAccessTime = session.lastAccessTime
@@ -569,7 +569,7 @@ class TFrontendServiceSuite extends KyuubiFunSuite {
         assert(session.lastAccessTime > lastAccessTime)
       }
       info("session is terminated")
-      assert(sessionManager.getActiveUserSessionCount === 0)
+      assert(sessionManager.getOpenSessionCount === 0)
     }
   }
 
