@@ -103,6 +103,13 @@ object KyuubiApplicationManager {
     conf.set(SparkProcessBuilder.TAG_KEY, newTag)
   }
 
+  private def setupEngineYarnModeTag(tag: String, conf: KyuubiConf): Unit = {
+    val originalTag =
+      conf.getOption(KyuubiConf.ENGINE_DEPLOY_YARN_MODE_TAGS.key).map(_ + ",").getOrElse("")
+    val newTag = s"${originalTag}KYUUBI" + Some(tag).filterNot(_.isEmpty).map("," + _).getOrElse("")
+    conf.set(KyuubiConf.ENGINE_DEPLOY_YARN_MODE_TAGS.key, newTag)
+  }
+
   private def setupSparkK8sTag(tag: String, conf: KyuubiConf): Unit = {
     conf.set("spark.kubernetes.driver.label." + LABEL_KYUUBI_UNIQUE_KEY, tag)
   }
@@ -123,9 +130,8 @@ object KyuubiApplicationManager {
   }
 
   private[kyuubi] def checkApplicationAccessPath(path: String, conf: KyuubiConf): Unit = {
-    var localDirAllowList: Set[String] = conf.get(KyuubiConf.SESSION_LOCAL_DIR_ALLOW_LIST)
+    val localDirAllowList = conf.get(KyuubiConf.SESSION_LOCAL_DIR_ALLOW_LIST)
     if (localDirAllowList.nonEmpty) {
-      localDirAllowList ++= Set(uploadWorkDir.toUri.getPath)
       val uri =
         try {
           new URI(path)
@@ -183,6 +189,8 @@ object KyuubiApplicationManager {
         // running flink on other platforms is not yet supported
         setupFlinkYarnTag(applicationTag, conf)
       // other engine types are running locally yet
+      case ("HIVE", Some("YARN")) =>
+        setupEngineYarnModeTag(applicationTag, conf)
       case _ =>
     }
   }
