@@ -28,7 +28,6 @@ import io.swagger.v3.oas.annotations.media.{ArraySchema, Content, Schema}
 import io.swagger.v3.oas.annotations.responses.ApiResponse
 import io.swagger.v3.oas.annotations.tags.Tag
 import org.apache.commons.lang3.StringUtils
-import org.apache.hive.service.rpc.thrift.{TGetInfoType, TProtocolVersion}
 
 import org.apache.kyuubi.Logging
 import org.apache.kyuubi.client.api.v1.dto
@@ -37,6 +36,7 @@ import org.apache.kyuubi.config.KyuubiReservedKeys._
 import org.apache.kyuubi.operation.{KyuubiOperation, OperationHandle}
 import org.apache.kyuubi.server.api.{ApiRequestContext, ApiUtils}
 import org.apache.kyuubi.session.{KyuubiSession, SessionHandle}
+import org.apache.kyuubi.shaded.hive.service.rpc.thrift.{TGetInfoType, TProtocolVersion}
 
 @Tag(name = "Session")
 @Produces(Array(MediaType.APPLICATION_JSON))
@@ -69,26 +69,7 @@ private[v1] class SessionsResource extends ApiRequestContext with Logging {
   @Path("{sessionHandle}")
   def sessionInfo(@PathParam("sessionHandle") sessionHandleStr: String): dto.KyuubiSessionEvent = {
     try {
-      sessionManager.getSession(sessionHandleStr)
-        .asInstanceOf[KyuubiSession].getSessionEvent.map(event =>
-          dto.KyuubiSessionEvent.builder
-            .sessionId(event.sessionId)
-            .clientVersion(event.clientVersion)
-            .sessionType(event.sessionType)
-            .sessionName(event.sessionName)
-            .user(event.user)
-            .clientIp(event.clientIP)
-            .serverIp(event.serverIP)
-            .conf(event.conf.asJava)
-            .remoteSessionId(event.remoteSessionId)
-            .engineId(event.engineId)
-            .eventTime(event.eventTime)
-            .openedTime(event.openedTime)
-            .startTime(event.startTime)
-            .endTime(event.endTime)
-            .totalOperations(event.totalOperations)
-            .exception(event.exception.orNull)
-            .build).get
+      ApiUtils.sessionEvent(sessionManager.getSession(sessionHandleStr).asInstanceOf[KyuubiSession])
     } catch {
       case NonFatal(e) =>
         val errorMsg = s"Invalid $sessionHandleStr"
@@ -128,7 +109,7 @@ private[v1] class SessionsResource extends ApiRequestContext with Logging {
   @GET
   @Path("count")
   def sessionCount(): SessionOpenCount = {
-    new SessionOpenCount(sessionManager.getActiveUserSessionCount)
+    new SessionOpenCount(sessionManager.getOpenSessionCount)
   }
 
   @ApiResponse(
