@@ -41,7 +41,7 @@ class SparkProcessBuilderSuite extends KerberizedTestHelper with MockitoSugar {
   private def conf = KyuubiConf().set("kyuubi.on", "off")
 
   test("spark process builder") {
-    val builder = new SparkProcessBuilder("kentyao", conf)
+    val builder = new SparkProcessBuilder("kentyao", true, conf)
     val commands = builder.toString.split(' ')
     assert(commands(2) === "org.apache.kyuubi.engine.spark.SparkSQLEngine")
     assert(commands.contains("spark.kyuubi.on=off"))
@@ -57,7 +57,7 @@ class SparkProcessBuilderSuite extends KerberizedTestHelper with MockitoSugar {
   }
 
   test("capture error from spark process builder") {
-    val processBuilder = new SparkProcessBuilder("kentyao", conf.set("spark.ui.port", "abc"))
+    val processBuilder = new SparkProcessBuilder("kentyao", true, conf.set("spark.ui.port", "abc"))
     processBuilder.start
     eventually(timeout(90.seconds), interval(500.milliseconds)) {
       val error = processBuilder.getError
@@ -67,7 +67,10 @@ class SparkProcessBuilderSuite extends KerberizedTestHelper with MockitoSugar {
     }
 
     val processBuilder1 =
-      new SparkProcessBuilder("kentyao", conf.set("spark.hive.metastore.uris", "thrift://dummy"))
+      new SparkProcessBuilder(
+        "kentyao",
+        true,
+        conf.set("spark.hive.metastore.uris", "thrift://dummy"))
 
     processBuilder1.start
     eventually(timeout(90.seconds), interval(500.milliseconds)) {
@@ -79,7 +82,10 @@ class SparkProcessBuilderSuite extends KerberizedTestHelper with MockitoSugar {
 
   test("engine log truncation") {
     val pb =
-      new SparkProcessBuilder("kentyao", conf.set("spark.hive.metastore.uris", "thrift://dummy"))
+      new SparkProcessBuilder(
+        "kentyao",
+        true,
+        conf.set("spark.hive.metastore.uris", "thrift://dummy"))
     pb.start
     eventually(timeout(90.seconds), interval(500.milliseconds)) {
       val error1 = pb.getError
@@ -89,6 +95,7 @@ class SparkProcessBuilderSuite extends KerberizedTestHelper with MockitoSugar {
 
     val pb2 = new SparkProcessBuilder(
       "kentyao",
+      true,
       conf.set("spark.hive.metastore.uris", "thrift://dummy")
         .set(KyuubiConf.ENGINE_ERROR_MAX_SIZE, 200))
     pb2.start
@@ -99,7 +106,7 @@ class SparkProcessBuilderSuite extends KerberizedTestHelper with MockitoSugar {
     }
 
     val pb3 =
-      new SparkProcessBuilder("kentyao", conf.set("spark.kerberos.principal", testPrincipal))
+      new SparkProcessBuilder("kentyao", true, conf.set("spark.kerberos.principal", testPrincipal))
     pb3.start
     eventually(timeout(90.seconds), interval(500.milliseconds)) {
       val error1 = pb3.getError
@@ -110,29 +117,29 @@ class SparkProcessBuilderSuite extends KerberizedTestHelper with MockitoSugar {
   }
 
   test("proxy user or keytab") {
-    val b1 = new SparkProcessBuilder("kentyao", conf)
+    val b1 = new SparkProcessBuilder("kentyao", true, conf)
     assert(b1.toString.contains("--proxy-user kentyao"))
 
     val conf1 = conf.set("spark.kerberos.principal", testPrincipal)
-    val b2 = new SparkProcessBuilder("kentyao", conf1)
+    val b2 = new SparkProcessBuilder("kentyao", true, conf1)
     assert(b2.toString.contains("--proxy-user kentyao"))
 
     val conf2 = conf.set("spark.kerberos.keytab", testKeytab)
-    val b3 = new SparkProcessBuilder("kentyao", conf2)
+    val b3 = new SparkProcessBuilder("kentyao", true, conf2)
     assert(b3.toString.contains("--proxy-user kentyao"))
 
     tryWithSecurityEnabled {
       val conf3 = conf.set("spark.kerberos.principal", testPrincipal)
         .set("spark.kerberos.keytab", "testKeytab")
-      val b4 = new SparkProcessBuilder(Utils.currentUser, conf3)
+      val b4 = new SparkProcessBuilder(Utils.currentUser, true, conf3)
       assert(b4.toString.contains(s"--proxy-user ${Utils.currentUser}"))
 
       val conf4 = conf.set("spark.kerberos.principal", testPrincipal)
         .set("spark.kerberos.keytab", testKeytab)
-      val b5 = new SparkProcessBuilder("kentyao", conf4)
+      val b5 = new SparkProcessBuilder("kentyao", true, conf4)
       assert(b5.toString.contains("--proxy-user kentyao"))
 
-      val b6 = new SparkProcessBuilder(ServiceUtils.getShortName(testPrincipal), conf4)
+      val b6 = new SparkProcessBuilder(ServiceUtils.getShortName(testPrincipal), true, conf4)
       assert(!b6.toString.contains("--proxy-user kentyao"))
     }
   }
@@ -228,13 +235,13 @@ class SparkProcessBuilderSuite extends KerberizedTestHelper with MockitoSugar {
 
     val conf = KyuubiConf()
     conf.set(ENGINE_SPARK_MAIN_RESOURCE, hdfsPath)
-    val b1 = new SparkProcessBuilder("test", conf)
+    val b1 = new SparkProcessBuilder("test", true, conf)
     assert(b1.mainResource.get.startsWith("hdfs://"))
     assert(b1.mainResource.get == hdfsPath)
 
     // user specified jar not exist, get default jar and expect not equals
     conf.set(ENGINE_SPARK_MAIN_RESOURCE, jarPath.toString)
-    val b2 = new SparkProcessBuilder("test", conf)
+    val b2 = new SparkProcessBuilder("test", true, conf)
     assert(b2.mainResource.getOrElse("") != jarPath.toString)
   }
 
@@ -244,7 +251,7 @@ class SparkProcessBuilderSuite extends KerberizedTestHelper with MockitoSugar {
     conf.set("spark.vino", "yang")
     conf.set("kent", "yao")
     conf.set("hadoop.kent", "yao")
-    val builder = new SparkProcessBuilder("", conf)
+    val builder = new SparkProcessBuilder("", true, conf)
     val commands = builder.toString.split(' ')
     assert(commands.contains("spark.kyuubi.kent=yao"))
     assert(commands.contains("spark.vino=yang"))
@@ -258,14 +265,14 @@ class SparkProcessBuilderSuite extends KerberizedTestHelper with MockitoSugar {
     conf.set(HighAvailabilityConf.HA_ZK_AUTH_KEYTAB.key, testKeytab)
     conf.set(HighAvailabilityConf.HA_ZK_AUTH_PRINCIPAL.key, testPrincipal)
 
-    val b1 = new SparkProcessBuilder("test", conf)
+    val b1 = new SparkProcessBuilder("test", true, conf)
     assert(b1.toString.contains(s"--conf spark.files=$testKeytab"))
   }
 
   test("SparkProcessBuilder commands immutable") {
     val conf = KyuubiConf(false)
     val engineRefId = UUID.randomUUID().toString
-    val pb = new SparkProcessBuilder("", conf, engineRefId)
+    val pb = new SparkProcessBuilder("", true, conf, engineRefId)
     assert(pb.toString.contains(engineRefId))
     val engineRefId2 = UUID.randomUUID().toString
     conf.set("spark.yarn.tags", engineRefId2)
@@ -276,7 +283,7 @@ class SparkProcessBuilderSuite extends KerberizedTestHelper with MockitoSugar {
   test("SparkProcessBuilder build spark engine with SPARK_USER_NAME") {
     val proxyName = "kyuubi"
     val conf1 = KyuubiConf(false).set("spark.master", "k8s://test:12345")
-    val b1 = new SparkProcessBuilder(proxyName, conf1)
+    val b1 = new SparkProcessBuilder(proxyName, true, conf1)
     val c1 = b1.toString.split(' ')
     assert(c1.contains(s"spark.kubernetes.driverEnv.SPARK_USER_NAME=$proxyName"))
     assert(c1.contains(s"spark.executorEnv.SPARK_USER_NAME=$proxyName"))
@@ -286,7 +293,7 @@ class SparkProcessBuilderSuite extends KerberizedTestHelper with MockitoSugar {
         .set("spark.kerberos.principal", testPrincipal)
         .set("spark.kerberos.keytab", testKeytab)
       val name = ServiceUtils.getShortName(testPrincipal)
-      val b2 = new SparkProcessBuilder(name, conf2)
+      val b2 = new SparkProcessBuilder(name, true, conf2)
       val c2 = b2.toString.split(' ')
       assert(c2.contains(s"spark.kubernetes.driverEnv.SPARK_USER_NAME=$name"))
       assert(c2.contains(s"spark.executorEnv.SPARK_USER_NAME=$name"))
@@ -295,14 +302,14 @@ class SparkProcessBuilderSuite extends KerberizedTestHelper with MockitoSugar {
 
     // Test no-kubernetes case
     val conf3 = KyuubiConf(false)
-    val b3 = new SparkProcessBuilder(proxyName, conf3)
+    val b3 = new SparkProcessBuilder(proxyName, true, conf3)
     val c3 = b3.toString.split(' ')
     assert(!c3.contains(s"spark.kubernetes.driverEnv.SPARK_USER_NAME=$proxyName"))
     assert(!c3.contains(s"spark.executorEnv.SPARK_USER_NAME=$proxyName"))
   }
 
   test("[KYUUBI #5009] Test pass spark engine log path to spark conf") {
-    val b1 = new SparkProcessBuilder("kyuubi", conf)
+    val b1 = new SparkProcessBuilder("kyuubi", true, conf)
     assert(
       b1.toString.contains(
         s"$CONF spark.$KYUUBI_ENGINE_LOG_PATH_KEY=${b1.engineLog.getAbsolutePath}"))
@@ -313,6 +320,7 @@ class SparkProcessBuilderSuite extends KerberizedTestHelper with MockitoSugar {
     val appName = "test-app"
     val processBuilder = new SparkProcessBuilder(
       "kyuubi",
+      true,
       conf.set(MASTER_KEY, "k8s://internal").set(DEPLOY_MODE_KEY, "cluster"),
       engineRefId)
     val conf1 = Map(APP_KEY -> "test-app")
@@ -339,6 +347,7 @@ class SparkProcessBuilderSuite extends KerberizedTestHelper with MockitoSugar {
     assert(driverPodName4 === Some(s"kyuubi-test-$engineRefId-driver"))
     val newProcessBuilder = new SparkProcessBuilder(
       "kyuubi",
+      true,
       conf.set(MASTER_KEY, "k8s://internal").set(DEPLOY_MODE_KEY, "cluster").set(
         KUBERNETES_FORCIBLY_REWRITE_DRIVER_POD_NAME,
         true),
@@ -353,6 +362,7 @@ class SparkProcessBuilderSuite extends KerberizedTestHelper with MockitoSugar {
     val appName = "test-app"
     val processBuilder = new SparkProcessBuilder(
       "kyuubi",
+      true,
       conf.set(MASTER_KEY, "k8s://internal").set(DEPLOY_MODE_KEY, "cluster"),
       engineRefId)
     val conf1 = Map(APP_KEY -> "test-app")
@@ -375,6 +385,7 @@ class SparkProcessBuilderSuite extends KerberizedTestHelper with MockitoSugar {
     assert(execPodNamePrefix3 === Some(s"kyuubi-$engineRefId"))
     val newProcessBuilder = new SparkProcessBuilder(
       "kyuubi",
+      true,
       conf.set(MASTER_KEY, "k8s://internal").set(DEPLOY_MODE_KEY, "cluster").set(
         KUBERNETES_FORCIBLY_REWRITE_EXEC_POD_NAME_PREFIX,
         true),
@@ -386,7 +397,7 @@ class SparkProcessBuilderSuite extends KerberizedTestHelper with MockitoSugar {
   }
 
   test("extract spark core scala version") {
-    val builder = new SparkProcessBuilder("kentyao", KyuubiConf(false))
+    val builder = new SparkProcessBuilder("kentyao", true, KyuubiConf(false))
     Seq(
       "spark-core_2.13-3.4.1.jar",
       "spark-core_2.13-3.5.0-abc-20230921.jar",
@@ -428,30 +439,19 @@ class SparkProcessBuilderSuite extends KerberizedTestHelper with MockitoSugar {
   test("default spark.yarn.maxAppAttempts conf in yarn mode") {
     val conf1 = KyuubiConf(false)
     conf1.set("spark.master", "k8s://test:12345")
-    val builder1 = new SparkProcessBuilder("", conf1)
+    val builder1 = new SparkProcessBuilder("", true, conf1)
     val commands1 = builder1.toString.split(' ')
     assert(!commands1.contains("spark.yarn.maxAppAttempts"))
 
     val conf2 = KyuubiConf(false)
     conf2.set("spark.master", "yarn")
-    val builder2 = new SparkProcessBuilder("", conf2)
+    val builder2 = new SparkProcessBuilder("", true, conf2)
     val commands2 = builder2.toString.split(' ')
     assert(commands2.contains("spark.yarn.maxAppAttempts=1"))
   }
-
-  test("spark conf should be converted with `spark.` prefix") {
-    val kyuubiConf = KyuubiConf(false)
-    kyuubiConf.set("kyuubi.key", "value")
-    val builder = new SparkProcessBuilder(
-      "kyuubi",
-      kyuubiConf,
-      UUID.randomUUID().toString,
-      None)
-    assert(builder.commands.toSeq.contains("spark.kyuubi.key=value"))
-  }
 }
 
 class FakeSparkProcessBuilder(config: KyuubiConf)
-  extends SparkProcessBuilder("fake", config) {
-  override lazy val commands: Iterable[String] = Seq("ls")
+  extends SparkProcessBuilder("fake", true, config) {
+  override protected lazy val commands: Iterable[String] = Seq("ls")
 }
