@@ -19,13 +19,13 @@ package org.apache.kyuubi.server
 
 import scala.collection.JavaConverters._
 
-import org.apache.hive.service.rpc.thrift.{TOpenSessionReq, TSessionHandle}
 import org.scalatest.time.SpanSugar.convertIntToGrainOfTime
 
 import org.apache.kyuubi.{KyuubiFunSuite, Utils, WithKyuubiServer}
 import org.apache.kyuubi.config.KyuubiConf
 import org.apache.kyuubi.metrics.{MetricsConstants, MetricsSystem}
 import org.apache.kyuubi.operation.TClientTestUtils
+import org.apache.kyuubi.shaded.hive.service.rpc.thrift.{TOpenSessionReq, TSessionHandle}
 
 class KyuubiTBinaryFrontendServiceSuite extends WithKyuubiServer with KyuubiFunSuite {
 
